Working with observations
=========================

From GRDC data
--------------

For reading GRDC data, working with a python-object can be done like this.

.. autoclass:: obs_data.grdc_data
    :members:

From other sources
------------------

For reading other data sources

.. autoclass:: obs_data.other_data
    :members: